@@ -1,20 +1,20 @@
 // SPDX-FileCopyrightText: 2022 James R. Barlow
 // SPDX-License-Identifier: MPL-2.0
 
-#include <cstring>
 #include <cctype>
+#include <cstring>
 
+#include <qpdf/Buffer.hh>
 #include <qpdf/Constants.h>
-#include <qpdf/Types.h>
 #include <qpdf/DLL.h>
 #include <qpdf/Pl_String.hh>
+#include <qpdf/QPDF.hh>
 #include <qpdf/QPDFExc.hh>
 #include <qpdf/QPDFObjGen.hh>
-#include <qpdf/QPDFXRefEntry.hh>
-#include <qpdf/Buffer.hh>
 #include <qpdf/QPDFObjectHandle.hh>
-#include <qpdf/QPDF.hh>
 #include <qpdf/QPDFWriter.hh>
+#include <qpdf/QPDFXRefEntry.hh>
+#include <qpdf/Types.h>
 
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
@@ -61,138 +61,6 @@ py::size_t list_range_check(QPDFObjectHandle h, int index)
     return static_cast<py::size_t>(index);
 }
 
-inline bool typecode_is_bool(qpdf_object_type_e typecode)
-{
-    return typecode == qpdf_object_type_e::ot_boolean;
-}
-
-inline bool typecode_is_int(qpdf_object_type_e typecode)
-{
-    return typecode == qpdf_object_type_e::ot_integer;
-}
-
-inline bool typecode_is_numeric(qpdf_object_type_e typecode)
-{
-    return typecode == qpdf_object_type_e::ot_integer ||
-           typecode == qpdf_object_type_e::ot_real ||
-           typecode == qpdf_object_type_e::ot_boolean;
-}
-
-bool objecthandle_equal(QPDFObjectHandle self, QPDFObjectHandle other)
-{
-    StackGuard sg(" objecthandle_equal");
-
-    // Uninitialized objects are never equal
-    if (!self.isInitialized() || !other.isInitialized())
-        return false; // LCOV_EXCL_LINE
-
-    // If two objects point to the same underlying object, they are equal (in fact,
-    // they are identical; they reference the same underlying QPDFObject, even if the
-    // handles are different). This lets us compare deeply nested and cyclic
-    // structures without recursing into them.
-    if (self.isSameObjectAs(other)) {
-        return true;
-    }
-
-    auto self_typecode  = self.getTypeCode();
-    auto other_typecode = other.getTypeCode();
-
-    if (typecode_is_bool(self_typecode) && typecode_is_bool(other_typecode)) {
-        return self.getBoolValue() == other.getBoolValue();
-    } else if (typecode_is_int(self_typecode) && typecode_is_int(other_typecode)) {
-        return self.getIntValue() == other.getIntValue();
-    } else if (typecode_is_numeric(self_typecode) &&
-               typecode_is_numeric(other_typecode)) {
-        // If 'self' and 'other' are different numeric types, convert both to
-        // Decimal objects and compare them as such.
-        auto a              = decimal_from_pdfobject(self);
-        auto b              = decimal_from_pdfobject(other);
-        py::object pyresult = a.attr("__eq__")(b);
-        bool result         = pyresult.cast<bool>();
-        return result;
-    }
-
-    // Apart from numeric types, dissimilar types are never equal
-    if (self_typecode != other_typecode)
-        return false;
-
-    switch (self_typecode) {
-    case qpdf_object_type_e::ot_null:
-        return true; // Both must be null
-    case qpdf_object_type_e::ot_name:
-        return self.getName() == other.getName();
-    case qpdf_object_type_e::ot_operator:
-        return self.getOperatorValue() == other.getOperatorValue();
-    case qpdf_object_type_e::ot_string: {
-        // We don't know what encoding the string is in
-        // This ensures UTF-16 coded ASCII strings will compare equal to
-        // UTF-8/ASCII coded.
-        return self.getStringValue() == other.getStringValue() ||
-               self.getUTF8Value() == other.getUTF8Value();
-    }
-    case qpdf_object_type_e::ot_array: {
-        // Call operator==() on each element of the arrays, meaning this
-        // recurses into this function
-        if (self.getArrayNItems() != other.getArrayNItems())
-            return false;
-        {
-            auto self_aitems  = self.aitems();
-            auto other_aitems = other.aitems();
-            auto iter_self    = self_aitems.begin();
-            auto iter_other   = other_aitems.begin();
-            for (; iter_self != self_aitems.end(); ++iter_self, ++iter_other) {
-                if (!objecthandle_equal(*iter_self, *iter_other))
-                    return false;
-            }
-        }
-        return true;
-    }
-    case qpdf_object_type_e::ot_dictionary: {
-        // Call operator==() on each element of the arrays, meaning this
-        // recurses into this function
-        return (self.getDictAsMap() == other.getDictAsMap());
-    }
-    case qpdf_object_type_e::ot_stream: {
-        // Recurse into this function to check if our dictionaries are equal
-        if (!objecthandle_equal(self.getDict(), other.getDict()))
-            return false;
-
-        // If dictionaries are equal, check our stream
-        // We don't go as far as decompressing the data to see if it's equal
-        auto self_buffer  = self.getRawStreamData();
-        auto other_buffer = other.getRawStreamData();
-
-        // Early out: if underlying qpdf Buffers happen to be the same, the data is
-        // the same
-        if (self_buffer == other_buffer)
-            return true;
-        // Early out: if sizes are different, data cannot be the same
-        if (self_buffer->getSize() != other_buffer->getSize())
-            return false;
-
-        // Slow path: memcmp the binary data
-        return 0 == std::memcmp(self_buffer->getBuffer(),
-                        other_buffer->getBuffer(),
-                        self_buffer->getSize());
-    }
-    // LCOV_EXCL_START
-    case qpdf_object_type_e::ot_boolean:
-    case qpdf_object_type_e::ot_integer:
-    case qpdf_object_type_e::ot_real:
-        throw std::logic_error("should have eliminated numeric types by now");
-    default:
-        throw std::logic_error("invalid object type");
-    }
-    // LCOV_EXCL_STOP
-}
-
-bool operator==(QPDFObjectHandle self, QPDFObjectHandle other)
-{
-    // A lot of functions in QPDFObjectHandle are not tagged const where they
-    // should be, but are const-safe
-    return objecthandle_equal(self, other);
-}
-
 bool object_has_key(QPDFObjectHandle h, std::string const &key)
 {
     if (!h.isDictionary() && !h.isStream())
@@ -352,7 +220,7 @@ void init_object(py::module_ &m)
             })
         .def("with_same_owner_as",
             [](QPDFObjectHandle &self, QPDFObjectHandle &other) {
-                QPDF *self_owner  = self.getOwningQPDF();
+                QPDF *self_owner = self.getOwningQPDF();
                 QPDF *other_owner = other.getOwningQPDF();
 
                 if (self_owner == other_owner)
@@ -483,7 +351,7 @@ void init_object(py::module_ &m)
                     return nitems > 0;
                 } else if (h.isStream()) {
                     auto stream_dict = h.getDict();
-                    auto len         = stream_dict.getKey("/Length");
+                    auto len = stream_dict.getKey("/Length");
                     if (len.isNull() || !len.isInteger() || len.getIntValue() <= 0) {
                         return false;
                     }
@@ -558,7 +426,7 @@ void init_object(py::module_ &m)
                 if (h.isDictionary() || (h.isStream() && name != "stream_dict")) {
                     // Map attribute assignment to setting dictionary key
                     std::string key = "/" + name;
-                    auto value      = objecthandle_encode(pyvalue);
+                    auto value = objecthandle_encode(pyvalue);
                     object_set_key(h, key, value);
                     return;
                 }
@@ -652,13 +520,13 @@ void init_object(py::module_ &m)
             "__iter__",
             [](QPDFObjectHandle h) -> py::iterable {
                 if (h.isArray()) {
-                    auto vec   = h.getArrayAsVector();
+                    auto vec = h.getArrayAsVector();
                     auto pyvec = py::cast(vec);
                     return pyvec.attr("__iter__")();
                 } else if (h.isDictionary() || h.isStream()) {
                     if (h.isStream())
                         h = h.getDict();
-                    auto keys   = h.getKeys();
+                    auto keys = h.getKeys();
                     auto pykeys = py::cast(keys);
                     return pykeys.attr("__iter__")();
                 } else {
@@ -673,7 +541,7 @@ void init_object(py::module_ &m)
                     h = h.getDict();
                 if (!h.isDictionary())
                     throw py::type_error("items() not available on this type");
-                auto dict   = h.getDictAsMap();
+                auto dict = h.getDictAsMap();
                 auto pydict = py::cast(dict);
                 return pydict.attr("items")();
             },
@@ -716,7 +584,7 @@ void init_object(py::module_ &m)
         .def("__setitem__",
             [](QPDFObjectHandle &h, int index, py::object pyvalue) {
                 auto u_index = list_range_check(h, index);
-                auto value   = objecthandle_encode(pyvalue);
+                auto value = objecthandle_encode(pyvalue);
                 h.setArrayItem(u_index, value);
             })
         .def("__delitem__",
@@ -766,8 +634,8 @@ void init_object(py::module_ &m)
                 py::bytes data,
                 py::object filter,
                 py::object decode_parms) {
-                std::string sdata               = data;
-                QPDFObjectHandle h_filter       = objecthandle_encode(filter);
+                std::string sdata = data;
+                QPDFObjectHandle h_filter = objecthandle_encode(filter);
                 QPDFObjectHandle h_decode_parms = objecthandle_encode(decode_parms);
                 h.replaceStreamData(sdata, h_filter, h_decode_parms);
             },
@@ -814,7 +682,7 @@ void init_object(py::module_ &m)
                 auto name = h.getUniqueResourceName(prefix, min_suffix);
                 return std::pair(name, min_suffix);
             },
-            py::arg("prefix")     = "",
+            py::arg("prefix") = "",
             py::arg("min_suffix") = 0)
         .def("_get_resource_names",
             [](QPDFObjectHandle &h) { return h.getResourceNames(); })
@@ -829,14 +697,14 @@ void init_object(py::module_ &m)
         .def(
             "to_json",
             [](QPDFObjectHandle &h,
-                bool dereference   = false,
+                bool dereference = false,
                 int schema_version = 2) -> py::bytes {
                 std::string result;
                 Pl_String p("json", nullptr, result);
                 h.writeJSON(schema_version, &p, dereference);
                 return result;
             },
-            py::arg("dereference")    = false,
+            py::arg("dereference") = false,
             py::arg("schema_version") = 2); // end of QPDFObjectHandle bindings
 
     m.def("_new_boolean", &QPDFObjectHandle::newBool);
